package com.upay.sdk.entity;

import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.ConfigurationUtils;
import com.upay.sdk.RSAUtils;
import com.upay.sdk.SignUtils;
import com.upay.sdk.builder.BuilderSupport;
import com.upay.sdk.core.CipherWrapper;
import com.upay.sdk.exception.UnknownException;
import org.apache.commons.lang3.StringUtils;

public class TerminalNoBuilder extends BuilderSupport {

    private String partnerId;
    private String merchantId;
    private String requestId;
    private String reportSerialNo;
    private String reportType;
    private String operationId;
    private String reportTerminalNo;
    private String deviceType;
    private String deviceSerialNo;
    private DeviceAddressInfo deviceAddressInfo;

    protected String orderGenerateHmac() {
        return SignUtils.signMd5(super.orderGenerateHmac(), ConfigurationUtils.getHmacKey(this.merchantId));
    }

    public JSONObject encryptBuild() {
        JSONObject json = super.assembleBuild();
        json.put("hmac", this.orderGenerateHmac());
        return StringUtils.isNotBlank(this.partnerId) ? CipherWrapper.bothEncryptWrap(this.merchantId, this.partnerId, json) : CipherWrapper.encryptWrap(this.merchantId, json);
    }

    public JSONObject bothEncryptBuild() {
        JSONObject json = super.assembleBuild();

        try {
            json.put("hmac", this.bothOrderGenerateHmac());
        } catch (Exception var3) {
            throw new UnknownException(var3);
        }

        return StringUtils.isNotBlank(this.partnerId) ? CipherWrapper.bothEncryptWrap(this.merchantId, this.partnerId, json) : CipherWrapper.bothEncryptWrap(this.merchantId, json);
    }

    protected byte[] bothOrderGenerateHmac() throws Exception {
        return RSAUtils.encryptSHA(super.orderGenerateHmac().getBytes("UTF-8"));
    }


    public String getPartnerId() {
        return partnerId;
    }

    public void setPartnerId(String partnerId) {
        this.partnerId = partnerId;
    }

    public String getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(String merchantId) {
        this.merchantId = merchantId;
    }

    public String getRequestId() {
        return requestId;
    }

    public void setRequestId(String requestId) {
        this.requestId = requestId;
    }

    public String getReportSerialNo() {
        return reportSerialNo;
    }

    public void setReportSerialNo(String reportSerialNo) {
        this.reportSerialNo = reportSerialNo;
    }

    public String getReportType() {
        return reportType;
    }

    public void setReportType(String reportType) {
        this.reportType = reportType;
    }

    public String getOperationId() {
        return operationId;
    }

    public void setOperationId(String operationId) {
        this.operationId = operationId;
    }

    public String getReportTerminalNo() {
        return reportTerminalNo;
    }

    public void setReportTerminalNo(String reportTerminalNo) {
        this.reportTerminalNo = reportTerminalNo;
    }

    public String getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(String deviceType) {
        this.deviceType = deviceType;
    }

    public String getDeviceSerialNo() {
        return deviceSerialNo;
    }

    public void setDeviceSerialNo(String deviceSerialNo) {
        this.deviceSerialNo = deviceSerialNo;
    }

    public DeviceAddressInfo getDeviceAddressInfo() {
        return deviceAddressInfo;
    }

    public void setDeviceAddressInfo(DeviceAddressInfo deviceAddressInfo) {
        this.deviceAddressInfo = deviceAddressInfo;
    }
}
