package com.upay.sdk.entity;


import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.Feature;
import com.upay.sdk.ConfigurationUtils;
import com.upay.sdk.Constants;
import com.upay.sdk.HttpClientUtils;
import com.upay.sdk.core.CipherWrapper;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.Executer;
import com.upay.sdk.executer.ResultListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class TerminalNoExecuter extends Executer {

    static final Logger LOGGER = LoggerFactory.getLogger(TerminalNoExecuter.class);

    public TerminalNoExecuter() {
    }

    public void terminalReport(TerminalNoBuilder builder, ResultListener resultListener) {
        try {
            JSONObject requestData = builder.bothEncryptBuild();
            LOGGER.debug("TerminalNoExecuter requestData:[" + requestData.toJSONString() + "]");
            String serviceProviderTerminalReportUrl = ConfigurationUtils.getServiceProviderTerminalReportUrl();
            LOGGER.info("TerminalNoExecuter url:[" + serviceProviderTerminalReportUrl + "]");
            String responseStr = HttpClientUtils.post3(serviceProviderTerminalReportUrl, requestData);
            LOGGER.info("TerminalNoExecuter responseStr:[" + responseStr + "]");
            JSONObject responseData = JSONObject.parseObject(responseStr, new Feature[]{Feature.SortFeidFastMatch});
            responseData = CipherWrapper.bothDecryptWrap(responseData);
            LOGGER.info("TerminalNoExecuter responseData:[" + responseData + "]");
            String status = responseData.getString(Constants.STATUS);
            if (Constants.ERROR.equals(status)) {
                throw new ResponseException(responseData);
            } else {
                this.bothVerifyHmacOrder(responseData);
                if (Constants.SUCCESS.equals(status)) {
                    resultListener.success(responseData);
                } else {
                    if (!Constants.FAILED.equals(status)) {
                        throw new ResponseException(responseData);
                    }

                    resultListener.failure(responseData);
                }

            }
        } catch (Exception var8) {
            LOGGER.error("TerminalNoExecuter error", var8);
            throw new UnknownException(var8);
        }
    }

    public void callBack(JSONObject responseData, ResultListener listener) {
        if (listener == null) {
            throw new NullPointerException();
        } else {
            LOGGER.info("TerminalNoExecuter callBack responseStr:[" + responseData + "]");
            JSONObject data = CipherWrapper.bothDecryptWrap(responseData);
            LOGGER.info("TerminalNoExecuter callBack responseData:[" + data + "]");
            this.bothVerifyHmacOrder(data);
            listener.success(data);
        }
    }
}
